mercurial/ui.py
changeset 40717 c72a81bc2e82
parent 40649 c36175456350
child 40764 55b053af7196
--- a/mercurial/ui.py	Sun Nov 11 17:45:18 2018 +0900
+++ b/mercurial/ui.py	Sun Nov 11 17:59:23 2018 +0900
@@ -1709,10 +1709,10 @@
         '''exists only so low-level modules won't need to import scmutil'''
         return scmutil.progress(self, topic, unit, total)
 
-    def log(self, service, *msg, **opts):
+    def log(self, event, *msg, **opts):
         '''hook for logging facility extensions
 
         service should be a readily-identifiable subsystem, which will
         allow filtering.
 
         *msg should be a newline-terminated format string to log, and
@@ -1709,10 +1709,10 @@
         '''hook for logging facility extensions
 
-        service should be a readily-identifiable subsystem, which will
+        event should be a readily-identifiable subsystem, which will
         allow filtering.
 